@@ -81,9 +81,14 @@ class GatewayServer(threading.Thread):
       output = MessageToDict(raw_output, preserving_proto_field_name=True)
       return JSONResponse(output)
     except Exception as ex:
-      grpc_status = ex._state.code.name
-      http_status_code = self.get_http_status(StatusCode[grpc_status])
-      raise HTTPException(http_status_code, ex._state.details)
+      if '_state' in ex:
+        detail = ex._state.details
+        grpc_status = ex._state.code.name
+        http_status_code = self.get_http_status(StatusCode[grpc_status])
+      else:
+        detail = str(ex)
+        http_status_code = 500
+      raise HTTPException(http_status_code, detail=detail)
 
   async def http_exception(self, request, exc):
     if 'favicon.ico' not in str(request.url):
